@@ -130,6 +130,7 @@ class Bootstrap:
     """Bootstrap a website."""
 
     def setup(self, add_arg):
+        add_arg("website", help="name of website")
         add_arg("package", help="name of PyPI package to install")
         add_arg("app", help="name of web app to run")
 
@@ -159,64 +160,55 @@ class Bootstrap:
         #     console.print(f"Registrar {config['registrar']} not available.")
         #     return 1
 
-        machines = config.get("machines", [])
-        if len(machines) == 0:
-            # XXX console.print("No machines found")
-            versions = web.host.Machine.versions
-            start_time = time.time()
-            total_time = 15
-            with console.status(
-                f"[bold green]around {total_time} minutes remaining"
-            ) as status:
+        machines = config.get("machines", {})
+        versions = web.host.Machine.versions
+        start_time = time.time()
+        total_time = 15
+        with console.status(
+            f"[bold green]around {total_time} minutes remaining"
+        ) as status:
 
-                def update_status():
-                    while True:
-                        remaining_time = total_time - round(
-                            (time.time() - start_time) / 60
-                        )
-                        if remaining_time < 1:
-                            status.update("Finishing up..")
-                            return
-                        status.update(
-                            f"[bold green]around {remaining_time} minutes remaining"
-                        )
-                        gevent.sleep(1)
+            def update_status():
+                while True:
+                    remaining_time = total_time - round((time.time() - start_time) / 60)
+                    if remaining_time < 1:
+                        status.update("Finishing up..")
+                        return
+                    status.update(
+                        f"[bold green]around {remaining_time} minutes remaining"
+                    )
+                    gevent.sleep(1)
 
-                gevent.spawn(update_status)
+            gevent.spawn(update_status)
 
-                # console.print(f"Spawning virtual machine at {host.__class__.__name__}")
-                # machine = web.host.spawn_machine("website", host)
-                # console.print("Updating system")
-                # machine._apt("update")
-                # console.print("Installing firewall")
-                # machine._apt("install -yq ufw")
-                # machine.open_ports(22)
-                # console.print("Setting up system")
-                # machine.setup_machine()
-                # console.print("Installing python")
-                # machine.setup_python()
-                # console.print("Installing tor")
-                # machine.setup_tor()
-
-                machine = web.host.Machine("143.198.60.50", "root", "gaea_key")
-                machine.onion = "foo.onion"
-
-                console.print("Installing nginx")
-                machine.setup_nginx()
-                # console.print(f"Installing application: {self.app} of {self.package}")
-                # machine.setup_app(self.package, self.app)
-
-                time.sleep(3)
-                webbrowser.open(f"http://{machine.address}")
-
-                return 0
-
-                machines.append(machine.address)
-                update_config(machines=machines)
-        machine = web.host.Machine(machines[0], "root", "gaea_key")
-        console.rule(f"[green]Using {machine.address}")
-        # with console.status("[bold blue]Installing/upgrading sites"):
-        #     machine.install_project(registrar)
+            console.print(f"Spawning virtual machine at {host.__class__.__name__}")
+            machine = web.host.spawn_machine(self.website, host)
+            console.print("Updating system")
+            machine._apt("update")
+            console.print("Installing firewall")
+            machine._apt("install -yq ufw")
+            machine.open_ports(22)
+            console.print("Setting up system")
+            machine.setup_machine()
+            console.print("Installing python")
+            machine.setup_python()
+            console.print("Installing tor")
+            machine.setup_tor()
+            # XXX machine = web.host.Machine("143.110.230.47", "root", "gaea_key")
+            # XXX machine.onion = (
+            # XXX   "izxwrqchdaqpj2iphrqoh6govp4dqolem4epoxv2nijqvlo5q3kbd5qd.onion"
+            # XXX )
+            console.print("Installing nginx")
+            machine.setup_nginx()
+            console.print(f"Installing application: {self.app} of {self.package}")
+            machine.setup_app(self.package, self.app)
+            time.sleep(2)
+        console.rule(
+            f"[green]Bootstrapped {self.package} ({self.app}) at {machine.address}"
+        )
+        webbrowser.open(f"https://{machine.address}")
+        machines[self.website] = machine.address
+        update_config(machines=machines)
         return 0
 
 
