@@ -310,6 +310,7 @@ class Machine(MachineBase):
         "haveged",  # produces entropy for faster key generation
         "sqlite3",  # SQLite flat-file relational database
         "libssl-dev",  # uWSGI SSL support
+        "apache2-utils",  # htpasswd for canopy+git support
         "ffmpeg",  # a/v en/de[code]
         "imagemagick",  # heic -> jpeg
         "libsm-dev",
@@ -414,12 +415,16 @@ class Machine(MachineBase):
             f"cat > {self.nginx_conf}",
             stdin=str(templates.nginx_conf(self.address, self.onion)),
         )
+
         self.user = "gaea"
+
+        # streaming server
         streaming_dir = "/home/gaea/app/run/media/streaming"
         self.run(f"mkdir {streaming_dir} -p")
         self.run(f"mkdir {streaming_dir}/hls")
         self.run(f"mkdir {streaming_dir}/rec")
 
+        # self-signed TLS certificate for IP address
         domain_cnf = configparser.ConfigParser()
         domain_cnf.optionxform = str
         domain_cnf["req"] = {
@@ -443,9 +448,25 @@ class Machine(MachineBase):
             "sudo openssl req -x509 -nodes -days 365 -newkey rsa:2048"
             " -keyout /etc/ssl/private/ip-selfsigned.key"
             " -out /etc/ssl/certs/ip-selfsigned.crt"
-            " -config ip-selfsigned.cnf"
+            " -config /home/gaea/app/run/ip-selfsigned.cnf"
         )
+
         self.user = "root"
+
+        # git server
+        self.run(
+            "git config --file=/lib/systemd/system/fcgiwrap.service Service.User gaea"
+        )
+        self.run(
+            "git config --file=/lib/systemd/system/fcgiwrap.service Service.Group gaea"
+        )
+        self.run("systemctl daemon-reload")
+        self.run("service fcgiwrap restart")
+
+        # get onion
+        self.run("cp /var/lib/tor/main/hostname /home/gaea/app/run/onion")
+        self.run("chown gaea:gaea /home/gaea/app/run/onion")
+
         self.generate_dhparam(512)  # NOTE 2048 adds ? minutes
         self.run("service nginx restart")
 
